@@ -1,9 +1,10 @@
 import contextlib
+import os
 from httpx import AsyncClient, Timeout, HTTPStatusError, HTTPError, Response, NetworkError
 import json
 from sentry_sdk import capture_message
 from http.client import HTTPException
-from sentry_sdk import init, capture_message
+from sentry_sdk import capture_exception
 
 
 class CustomHttpRequest:
@@ -33,7 +34,8 @@ class CustomHttpRequest:
                 res = self.create_error_response(status_code, e.response.text, "no_id")
 
             except HTTPError as e:
-                event_id = str(capture_message(e))
+                event_id = str(capture_exception(e))
+                print(f"event_id : {event_id}")
                 message = str(e)
                 res = self.create_error_response(status_code, message, event_id)
 
